<?php

namespace Schaffen\Gef\Services;

use App\Http\Utils\SCHArray;
use Schaffen\Gef\Models\ApontamentoVeiculoGastoItem;
use Schaffen\Gef\Repositories\ApontamentoVeiculoGastoItemRepository;
use Schaffen\Gef\Validators\ApontamentoVeiculoGastoItemValidator;
use Prettus\Validator\Exceptions\ValidatorException;

class ApontamentoVeiculoGastoItemService
{

   private $repository;
   private $validator;

    public function __construct(ApontamentoVeiculoGastoItemRepository $repository, ApontamentoVeiculoGastoItemValidator $validator)
    {
       $this->repository = $repository;
       $this->validator = $validator;
    }

   public function updateOrCreate($data, $codigo = null)
   {
      try {

         $attrib = ['avgi_codigo' => $codigo];

         $validator_rules = is_numeric($codigo) ? ApontamentoVeiculoGastoItemValidator::RULE_UPDATE : ApontamentoVeiculoGastoItemValidator::RULE_CREATE;
         $this->validator->with($data)->passesOrFail($validator_rules);
         $this->repository->setPresenter("Schaffen\\Gef\\Presenters\\ApontamentoVeiculoGastoItemPresenter");



         $data['fk_prfr_codigo'] = $data['produto'];
         $data['fk_avg_codigo'] = $data['apontamento_gasto'];

         $data = SCHArray::addPrefix(ApontamentoVeiculoGastoItem::$prefix, $data);
         $apontamento_gasto_item = $this->repository->updateOrCreate($attrib, $data);

         $response = [
            'status' => true,
            'errors' => '',
            'message' => 'Apontamento de gasto gravado.',
            'data' => $apontamento_gasto_item['data'],
            'http_code' => '200'
         ];


         return $response;

      }catch (\Exception $e) {
         throw $e;
      }
   }
}
